Separator

Enum Separator 

pub enum Separator {
    Trailing(Symbol),
    Proper(Symbol),
    Liberal(Symbol),
    Null,
}
The separator symbol and mode of separation in a sequence, or Null for no separation.

Variants



Trailing(Symbol)

Separation with the trailing separator included. In other words, all elements are followed by the separator.



Proper(Symbol)

The separator occurs between elements.



Liberal(Symbol)

The union of Trailing and Proper. In other words, the trailing separator may or may not be present.



Null

No separation.

Implementations

Source

impl Separator

pub fn prefix_separator(self) -> Self

Returns the kind of separation for a prefix sequence.