Sequence

Struct Sequence 

pub struct Sequence {
    pub lhs: Symbol,
    pub rhs: Symbol,
    pub start: u32,
    pub end: Option<u32>,
    pub separator: Separator,
    pub history: Option<History>,
}
Sequence rule representation.

Fields

lhs: Symbol

The rule’s left-hand side.

rhs: Symbol

The rule’s right-hand side.

start: u32

The minimum number of repetitions.

end: Option<u32>

Either the inclusive maximum number of repetitions, or None if the number of repetitions is unlimited.

separator: Separator

The way elements are separated in a sequence, or Null.

history: Option<History>

The history carried with the sequence rule.

Implementations

Source

impl Sequence

pub fn inclusive(self, start: u32, end: Option<u32>) -> Self

Assigns the inclusive range of the number of repetitions.

pub fn separator(self, sep: Separator) -> Self

Assigns the separator symbol and mode of separation.

pub fn range(self, range: impl RangeBounds<u32>) -> Self

Adds a range to the sequence.